@@ -27,6 +27,7 @@
 #include <gst/gstminiobject.h>
 #include <gst/gstclock.h>
 #include <gst/gstallocator.h>
+#include <gst/gstcaps.h>
 
 G_BEGIN_DECLS
 
@@ -180,55 +181,61 @@ typedef struct _GstBufferPool GstBufferPool;
 
 /**
  * GstBufferFlags:
- * @GST_BUFFER_FLAG_LIVE:        the buffer is live data and should be discarded in
- *                               the PAUSED state.
- * @GST_BUFFER_FLAG_DECODE_ONLY: the buffer contains data that should be dropped
- *                               because it will be clipped against the segment
- *                               boundaries or because it does not contain data
- *                               that should be shown to the user.
- * @GST_BUFFER_FLAG_DISCONT:     the buffer marks a data discontinuity in the stream.
- *                               This typically occurs after a seek or a dropped buffer
- *                               from a live or network source.
- * @GST_BUFFER_FLAG_RESYNC:      the buffer timestamps might have a discontinuity
- *                               and this buffer is a good point to resynchronize.
- * @GST_BUFFER_FLAG_CORRUPTED:   the buffer data is corrupted.
- * @GST_BUFFER_FLAG_MARKER:      the buffer contains a media specific marker. for
- *                               video this is typically the end of a frame boundary, for audio
- *                               this is usually the start of a talkspurt.
- * @GST_BUFFER_FLAG_HEADER:      the buffer contains header information that is
- *                               needed to decode the following data.
- * @GST_BUFFER_FLAG_GAP:         the buffer has been created to fill a gap in the
- *                               stream and contains media neutral data (elements can
- *                               switch to optimized code path that ignores the buffer
- *                               content).
- * @GST_BUFFER_FLAG_DROPPABLE:   the buffer can be dropped without breaking the
- *                               stream, for example to reduce bandwidth.
- * @GST_BUFFER_FLAG_DELTA_UNIT:  this unit cannot be decoded independently.
- * @GST_BUFFER_FLAG_TAG_MEMORY:  this flag is set when memory of the buffer
- *                               is added/removed
- * @GST_BUFFER_FLAG_SYNC_AFTER:  Elements which write to disk or permanent
+ * @GST_BUFFER_FLAG_LIVE:          the buffer is live data and should be discarded in
+ *                                 the PAUSED state.
+ * @GST_BUFFER_FLAG_DECODE_ONLY:   the buffer contains data that should be dropped
+ *                                 because it will be clipped against the segment
+ *                                 boundaries or because it does not contain data
+ *                                 that should be shown to the user.
+ * @GST_BUFFER_FLAG_DISCONT:       the buffer marks a data discontinuity in the stream.
+ *                                 This typically occurs after a seek or a dropped buffer
+ *                                 from a live or network source.
+ * @GST_BUFFER_FLAG_RESYNC:        the buffer timestamps might have a discontinuity
+ *                                 and this buffer is a good point to resynchronize.
+ * @GST_BUFFER_FLAG_CORRUPTED:     the buffer data is corrupted.
+ * @GST_BUFFER_FLAG_MARKER:        the buffer contains a media specific marker. for
+ *                                 video this is typically the end of a frame boundary, for audio
+ *                                 this is usually the start of a talkspurt.
+ * @GST_BUFFER_FLAG_HEADER:        the buffer contains header information that is
+ *                                 needed to decode the following data.
+ * @GST_BUFFER_FLAG_GAP:           the buffer has been created to fill a gap in the
+ *                                 stream and contains media neutral data (elements can
+ *                                 switch to optimized code path that ignores the buffer
+ *                                 content).
+ * @GST_BUFFER_FLAG_DROPPABLE:     the buffer can be dropped without breaking the
+ *                                 stream, for example to reduce bandwidth.
+ * @GST_BUFFER_FLAG_DELTA_UNIT:    this unit cannot be decoded independently.
+ * @GST_BUFFER_FLAG_TAG_MEMORY:    this flag is set when memory of the buffer
+ *                                 is added/removed
+ * @GST_BUFFER_FLAG_SYNC_AFTER:    Elements which write to disk or permanent
  * 				 storage should ensure the data is synced after
  * 				 writing the contents of this buffer. (Since 1.6)
- * @GST_BUFFER_FLAG_LAST:        additional media specific flags can be added starting from
- *                               this flag.
+ * @GST_BUFFER_FLAG_NON_DROPPABLE: This buffer is important and should not be dropped.
+ *                                 This can be used to mark important buffers, e.g. to flag
+ *                                 RTP packets carrying keyframes or codec setup data for RTP
+ *                                 Forward Error Correction purposes, or to prevent still video
+ *                                 frames from being dropped by elements due to QoS. (Since 1.14)
+ * @GST_BUFFER_FLAG_LAST:          additional media specific flags can be added starting from
+ *                                 this flag.
  *
  * A set of buffer flags used to describe properties of a #GstBuffer.
  */
 typedef enum {
-  GST_BUFFER_FLAG_LIVE        = (GST_MINI_OBJECT_FLAG_LAST << 0),
-  GST_BUFFER_FLAG_DECODE_ONLY = (GST_MINI_OBJECT_FLAG_LAST << 1),
-  GST_BUFFER_FLAG_DISCONT     = (GST_MINI_OBJECT_FLAG_LAST << 2),
-  GST_BUFFER_FLAG_RESYNC      = (GST_MINI_OBJECT_FLAG_LAST << 3),
-  GST_BUFFER_FLAG_CORRUPTED   = (GST_MINI_OBJECT_FLAG_LAST << 4),
-  GST_BUFFER_FLAG_MARKER      = (GST_MINI_OBJECT_FLAG_LAST << 5),
-  GST_BUFFER_FLAG_HEADER      = (GST_MINI_OBJECT_FLAG_LAST << 6),
-  GST_BUFFER_FLAG_GAP         = (GST_MINI_OBJECT_FLAG_LAST << 7),
-  GST_BUFFER_FLAG_DROPPABLE   = (GST_MINI_OBJECT_FLAG_LAST << 8),
-  GST_BUFFER_FLAG_DELTA_UNIT  = (GST_MINI_OBJECT_FLAG_LAST << 9),
-  GST_BUFFER_FLAG_TAG_MEMORY  = (GST_MINI_OBJECT_FLAG_LAST << 10),
-  GST_BUFFER_FLAG_SYNC_AFTER  = (GST_MINI_OBJECT_FLAG_LAST << 11),
+  GST_BUFFER_FLAG_LIVE          = (GST_MINI_OBJECT_FLAG_LAST << 0),
+  GST_BUFFER_FLAG_DECODE_ONLY   = (GST_MINI_OBJECT_FLAG_LAST << 1),
+  GST_BUFFER_FLAG_DISCONT       = (GST_MINI_OBJECT_FLAG_LAST << 2),
+  GST_BUFFER_FLAG_RESYNC        = (GST_MINI_OBJECT_FLAG_LAST << 3),
+  GST_BUFFER_FLAG_CORRUPTED     = (GST_MINI_OBJECT_FLAG_LAST << 4),
+  GST_BUFFER_FLAG_MARKER        = (GST_MINI_OBJECT_FLAG_LAST << 5),
+  GST_BUFFER_FLAG_HEADER        = (GST_MINI_OBJECT_FLAG_LAST << 6),
+  GST_BUFFER_FLAG_GAP           = (GST_MINI_OBJECT_FLAG_LAST << 7),
+  GST_BUFFER_FLAG_DROPPABLE     = (GST_MINI_OBJECT_FLAG_LAST << 8),
+  GST_BUFFER_FLAG_DELTA_UNIT    = (GST_MINI_OBJECT_FLAG_LAST << 9),
+  GST_BUFFER_FLAG_TAG_MEMORY    = (GST_MINI_OBJECT_FLAG_LAST << 10),
+  GST_BUFFER_FLAG_SYNC_AFTER    = (GST_MINI_OBJECT_FLAG_LAST << 11),
+  GST_BUFFER_FLAG_NON_DROPPABLE = (GST_MINI_OBJECT_FLAG_LAST << 12),
 
-  GST_BUFFER_FLAG_LAST        = (GST_MINI_OBJECT_FLAG_LAST << 16)
+  GST_BUFFER_FLAG_LAST          = (GST_MINI_OBJECT_FLAG_LAST << 16)
 } GstBufferFlags;
 
 /**
@@ -270,73 +277,133 @@ struct _GstBuffer {
   guint64                offset_end;
 };
 
+GST_EXPORT
 GType       gst_buffer_get_type            (void);
 
+GST_EXPORT
 guint       gst_buffer_get_max_memory      (void);
 
 /* allocation */
+
+GST_EXPORT
 GstBuffer * gst_buffer_new                 (void);
+
+GST_EXPORT
 GstBuffer * gst_buffer_new_allocate        (GstAllocator * allocator, gsize size,
                                             GstAllocationParams * params);
+GST_EXPORT
 GstBuffer * gst_buffer_new_wrapped_full    (GstMemoryFlags flags, gpointer data, gsize maxsize,
                                             gsize offset, gsize size, gpointer user_data,
                                             GDestroyNotify notify);
+GST_EXPORT
 GstBuffer * gst_buffer_new_wrapped         (gpointer data, gsize size);
 
 /* memory blocks */
+
+GST_EXPORT
 guint       gst_buffer_n_memory             (GstBuffer *buffer);
+
+GST_EXPORT
 void        gst_buffer_insert_memory        (GstBuffer *buffer, gint idx, GstMemory *mem);
+
+GST_EXPORT
 void        gst_buffer_replace_memory_range (GstBuffer *buffer, guint idx, gint length, GstMemory *mem);
+
+GST_EXPORT
 GstMemory * gst_buffer_peek_memory          (GstBuffer *buffer, guint idx);
+
+GST_EXPORT
 GstMemory * gst_buffer_get_memory_range     (GstBuffer *buffer, guint idx, gint length);
+
+GST_EXPORT
 void        gst_buffer_remove_memory_range  (GstBuffer *buffer, guint idx, gint length);
 
+GST_EXPORT
 void        gst_buffer_prepend_memory       (GstBuffer *buffer, GstMemory *mem);
+
+GST_EXPORT
 void        gst_buffer_append_memory        (GstBuffer *buffer, GstMemory *mem);
+
+GST_EXPORT
 void        gst_buffer_replace_memory       (GstBuffer *buffer, guint idx, GstMemory *mem);
+
+GST_EXPORT
 void        gst_buffer_replace_all_memory   (GstBuffer *buffer, GstMemory *mem);
+
+GST_EXPORT
 GstMemory * gst_buffer_get_memory           (GstBuffer *buffer, guint idx);
+
+GST_EXPORT
 GstMemory * gst_buffer_get_all_memory       (GstBuffer *buffer);
+
+GST_EXPORT
 void        gst_buffer_remove_memory        (GstBuffer *buffer, guint idx);
+
+GST_EXPORT
 void        gst_buffer_remove_all_memory    (GstBuffer *buffer);
 
+GST_EXPORT
 gboolean    gst_buffer_find_memory         (GstBuffer *buffer, gsize offset, gsize size,
                                             guint *idx, guint *length, gsize *skip);
-
+GST_EXPORT
 gboolean    gst_buffer_is_memory_range_writable  (GstBuffer *buffer, guint idx, gint length);
+
+GST_EXPORT
 gboolean    gst_buffer_is_all_memory_writable    (GstBuffer *buffer);
 
+GST_EXPORT
 gsize       gst_buffer_fill                (GstBuffer *buffer, gsize offset,
                                             gconstpointer src, gsize size);
+GST_EXPORT
 gsize       gst_buffer_extract             (GstBuffer *buffer, gsize offset,
                                             gpointer dest, gsize size);
+GST_EXPORT
 gint        gst_buffer_memcmp              (GstBuffer *buffer, gsize offset,
                                             gconstpointer mem, gsize size);
+GST_EXPORT
 gsize       gst_buffer_memset              (GstBuffer *buffer, gsize offset,
                                             guint8 val, gsize size);
-
+GST_EXPORT
 gsize       gst_buffer_get_sizes_range     (GstBuffer *buffer, guint idx, gint length,
                                             gsize *offset, gsize *maxsize);
+GST_EXPORT
 gboolean    gst_buffer_resize_range        (GstBuffer *buffer, guint idx, gint length,
                                             gssize offset, gssize size);
-
+GST_EXPORT
 gsize       gst_buffer_get_sizes           (GstBuffer *buffer, gsize *offset, gsize *maxsize);
+
+GST_EXPORT
 gsize       gst_buffer_get_size            (GstBuffer *buffer);
+
+GST_EXPORT
 void        gst_buffer_resize              (GstBuffer *buffer, gssize offset, gssize size);
+
+GST_EXPORT
 void        gst_buffer_set_size            (GstBuffer *buffer, gssize size);
 
+GST_EXPORT
 gboolean    gst_buffer_map_range           (GstBuffer *buffer, guint idx, gint length,
                                             GstMapInfo *info, GstMapFlags flags);
+GST_EXPORT
 gboolean    gst_buffer_map                 (GstBuffer *buffer, GstMapInfo *info, GstMapFlags flags);
 
+GST_EXPORT
 void        gst_buffer_unmap               (GstBuffer *buffer, GstMapInfo *info);
+
+GST_EXPORT
 void        gst_buffer_extract_dup         (GstBuffer *buffer, gsize offset,
                                             gsize size, gpointer *dest,
                                             gsize *dest_size);
-
+GST_EXPORT
 GstBufferFlags gst_buffer_get_flags        (GstBuffer * buffer);
+
+GST_EXPORT
 gboolean       gst_buffer_has_flags        (GstBuffer * buffer, GstBufferFlags flags);
+
+GST_EXPORT
 gboolean       gst_buffer_set_flags        (GstBuffer * buffer, GstBufferFlags flags);
+
+GST_EXPORT
 gboolean       gst_buffer_unset_flags      (GstBuffer * buffer, GstBufferFlags flags);
 
 
@@ -394,6 +461,7 @@ gst_buffer_copy (const GstBuffer * buf)
   return GST_BUFFER (gst_mini_object_copy (GST_MINI_OBJECT_CONST_CAST (buf)));
 }
 
+GST_EXPORT
 GstBuffer * gst_buffer_copy_deep (const GstBuffer * buf);
 
 /**
@@ -427,16 +495,16 @@ typedef enum {
 } GstBufferCopyFlags;
 
 /**
- * GST_BUFFER_COPY_METADATA:
+ * GST_BUFFER_COPY_METADATA: (value 7) (type GstBufferCopyFlags)
  *
  * Combination of all possible metadata fields that can be copied with
  * gst_buffer_copy_into().
  */
-#define GST_BUFFER_COPY_METADATA       (GST_BUFFER_COPY_FLAGS | GST_BUFFER_COPY_TIMESTAMPS |\
-                                        GST_BUFFER_COPY_META)
+#define GST_BUFFER_COPY_METADATA       ((GstBufferCopyFlags) (GST_BUFFER_COPY_FLAGS |\
+                                          GST_BUFFER_COPY_TIMESTAMPS | GST_BUFFER_COPY_META))
 
 /**
- * GST_BUFFER_COPY_ALL:
+ * GST_BUFFER_COPY_ALL: (value 15) (type GstBufferCopyFlags)
  *
  * Combination of all possible fields that can be copied with
  * gst_buffer_copy_into().
@@ -444,6 +512,8 @@ typedef enum {
 #define GST_BUFFER_COPY_ALL  ((GstBufferCopyFlags)(GST_BUFFER_COPY_METADATA | GST_BUFFER_COPY_MEMORY))
 
 /* copies memory or metadata into newly allocated buffer */
+
+GST_EXPORT
 gboolean        gst_buffer_copy_into            (GstBuffer *dest, GstBuffer *src,
                                                  GstBufferCopyFlags flags,
                                                  gsize offset, gsize size);
@@ -508,12 +578,17 @@ gst_buffer_replace (GstBuffer **obuf, GstBuffer *nbuf)
 }
 
 /* creating a region */
+
+GST_EXPORT
 GstBuffer*      gst_buffer_copy_region          (GstBuffer *parent, GstBufferCopyFlags flags,
                                                  gsize offset, gsize size);
 
 /* append two buffers */
+
+GST_EXPORT
 GstBuffer*      gst_buffer_append_region        (GstBuffer *buf1, GstBuffer *buf2,
                                                  gssize offset, gssize size);
+GST_EXPORT
 GstBuffer*      gst_buffer_append               (GstBuffer *buf1, GstBuffer *buf2);
 
 /* metadata */
@@ -540,17 +615,26 @@ GstBuffer*      gst_buffer_append               (GstBuffer *buf1, GstBuffer *buf
 typedef gboolean (*GstBufferForeachMetaFunc)    (GstBuffer *buffer, GstMeta **meta,
                                                  gpointer user_data);
 
+GST_EXPORT
 GstMeta *       gst_buffer_get_meta             (GstBuffer *buffer, GType api);
+
+GST_EXPORT
+guint           gst_buffer_get_n_meta           (GstBuffer *buffer, GType api_type);
+
+GST_EXPORT
 GstMeta *       gst_buffer_add_meta             (GstBuffer *buffer, const GstMetaInfo *info,
                                                  gpointer params);
+GST_EXPORT
 gboolean        gst_buffer_remove_meta          (GstBuffer *buffer, GstMeta *meta);
 
+GST_EXPORT
 GstMeta *       gst_buffer_iterate_meta         (GstBuffer *buffer, gpointer *state);
 
+GST_EXPORT
 GstMeta *       gst_buffer_iterate_meta_filtered (GstBuffer * buffer,
                                                   gpointer  * state,
                                                   GType       meta_api_type);
-
+GST_EXPORT
 gboolean        gst_buffer_foreach_meta         (GstBuffer *buffer,
                                                  GstBufferForeachMetaFunc func,
                                                  gpointer user_data);
@@ -609,6 +693,7 @@ struct _GstParentBufferMeta
   GstBuffer *buffer;
 };
 
+GST_EXPORT
 GType gst_parent_buffer_meta_api_get_type (void);
 #ifndef GST_DISABLE_DEPRECATED
 #define GST_TYPE_PARENT_BUFFER_META_API_TYPE GST_PARENT_BUFFER_META_API_TYPE
@@ -625,13 +710,67 @@ GType gst_parent_buffer_meta_api_get_type (void);
 #define gst_buffer_get_parent_buffer_meta(b) \
   ((GstParentBufferMeta*)gst_buffer_get_meta((b),GST_PARENT_BUFFER_META_API_TYPE))
 
+GST_EXPORT
 const GstMetaInfo *gst_parent_buffer_meta_get_info (void);
 #define GST_PARENT_BUFFER_META_INFO (gst_parent_buffer_meta_get_info())
 
 /* implementation */
+
+GST_EXPORT
 GstParentBufferMeta *gst_buffer_add_parent_buffer_meta (GstBuffer *buffer,
     GstBuffer *ref);
 
+typedef struct _GstReferenceTimestampMeta GstReferenceTimestampMeta;
+
+/**
+ * GstReferenceTimestampMeta:
+ * @parent: the parent #GstMeta structure
+ * @reference: identifier for the timestamp reference.
+ * @timestamp: timestamp
+ * @duration: duration, or %GST_CLOCK_TIME_NONE
+ *
+ * #GstReferenceTimestampMeta can be used to attach alternative timestamps and
+ * possibly durations to a #GstBuffer. These are generally not according to
+ * the pipeline clock and could be e.g. the NTP timestamp when the media was
+ * captured.
+ *
+ * The reference is stored as a #GstCaps in @reference. Examples of valid
+ * references would be "timestamp/x-drivername-stream" for timestamps that are locally
+ * generated by some driver named "drivername" when generating the stream,
+ * e.g. based on a frame counter, or "timestamp/x-ntp, host=pool.ntp.org,
+ * port=123" for timestamps based on a specific NTP server.
+ *
+ * Since: 1.14
+ */
+struct _GstReferenceTimestampMeta
+{
+  GstMeta parent;
+
+  /*< public >*/
+  GstCaps *reference;
+  GstClockTime timestamp, duration;
+};
+
+GST_EXPORT
+GType gst_reference_timestamp_meta_api_get_type (void);
+#define GST_REFERENCE_TIMESTAMP_META_API_TYPE (gst_reference_timestamp_meta_api_get_type())
+
+GST_EXPORT
+const GstMetaInfo *gst_reference_timestamp_meta_get_info (void);
+#define GST_REFERENCE_TIMESTAMP_META_INFO (gst_reference_timestamp_meta_get_info())
+
+/* implementation */
+
+GST_EXPORT
+GstReferenceTimestampMeta * gst_buffer_add_reference_timestamp_meta (GstBuffer  * buffer,
+                                                                     GstCaps    * reference,
+                                                                     GstClockTime timestamp,
+                                                                     GstClockTime duration);
+
+GST_EXPORT
+GstReferenceTimestampMeta * gst_buffer_get_reference_timestamp_meta (GstBuffer * buffer,
+                                                                     GstCaps   * reference);
+
 #ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
 G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstBuffer, gst_buffer_unref)
 #endif
