@@ -137,6 +137,7 @@ typedef struct _GstCaps GstCaps;
 typedef struct _GstStaticCaps GstStaticCaps;
 
 GST_EXPORT GstCaps * _gst_caps_any;
+
 GST_EXPORT GstCaps * _gst_caps_none;
 /**
  * GST_CAPS_FLAGS:
@@ -203,10 +204,6 @@ GST_EXPORT GstCaps * _gst_caps_none;
  *
  * Returns: the same #GstCaps object.
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstCaps * gst_caps_ref (GstCaps * caps);
-#endif
-
 static inline GstCaps *
 gst_caps_ref (GstCaps * caps)
 {
@@ -220,10 +217,6 @@ gst_caps_ref (GstCaps * caps)
  * Unref a #GstCaps and and free all its structures and the
  * structures' values when the refcount reaches 0.
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC void gst_caps_unref (GstCaps * caps);
-#endif
-
 static inline void
 gst_caps_unref (GstCaps * caps)
 {
@@ -246,10 +239,6 @@ gst_caps_unref (GstCaps * caps)
  *
  * Returns: the new #GstCaps
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC GstCaps * gst_caps_copy (const GstCaps * caps);
-#endif
-
 static inline GstCaps *
 gst_caps_copy (const GstCaps * caps)
 {
@@ -291,21 +280,17 @@ gst_caps_copy (const GstCaps * caps)
  * @old_caps: (inout) (transfer full) (nullable): pointer to a pointer
  *     to a #GstCaps to be replaced.
  * @new_caps: (transfer none) (allow-none): pointer to a #GstCaps that will
- *     replace the caps pointed to by @ocaps.
+ *     replace the caps pointed to by @old_caps.
  *
  * Modifies a pointer to a #GstCaps to point to a different #GstCaps. The
  * modification is done atomically (so this is useful for ensuring thread safety
  * in some cases), and the reference counts are updated appropriately (the old
  * caps is unreffed, the new is reffed).
  *
- * Either @ncaps or the #GstCaps pointed to by @ocaps may be %NULL.
+ * Either @new_caps or the #GstCaps pointed to by @old_caps may be %NULL.
  *
  * Returns: %TRUE if @new_caps was different from @old_caps
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC gboolean gst_caps_replace (GstCaps **old_caps, GstCaps *new_caps);
-#endif
-
 static inline gboolean
 gst_caps_replace (GstCaps **old_caps, GstCaps *new_caps)
 {
@@ -317,7 +302,7 @@ gst_caps_replace (GstCaps **old_caps, GstCaps *new_caps)
  * @old_caps: (inout) (transfer full): pointer to a pointer to a #GstCaps to be
  *     replaced.
  * @new_caps: (transfer full) (allow-none): pointer to a #GstCaps that will
- *     replace the caps pointed to by @ocaps.
+ *     replace the caps pointed to by @old_caps.
  *
  * Modifies a pointer to a #GstCaps to point to a different #GstCaps. This
  * function is similar to gst_caps_replace() except that it takes ownership
@@ -325,10 +310,6 @@ gst_caps_replace (GstCaps **old_caps, GstCaps *new_caps)
  *
  * Returns: %TRUE if @new_caps was different from @old_caps
  */
-#ifdef _FOOL_GTK_DOC_
-G_INLINE_FUNC gboolean gst_caps_take (GstCaps **old_caps, GstCaps *new_caps);
-#endif
-
 static inline gboolean
 gst_caps_take (GstCaps **old_caps, GstCaps *new_caps)
 {
@@ -363,100 +344,232 @@ struct _GstStaticCaps {
   gpointer _gst_reserved[GST_PADDING];
 };
 
+/**
+ * GstCapsForeachFunc:
+ * @features: the #GstCapsFeatures
+ * @structure: the #GstStructure
+ * @user_data: user data
+ *
+ * A function that will be called in gst_caps_foreach(). The function may
+ * not modify @features or @structure.
+ *
+ * Returns: %TRUE if the foreach operation should continue, %FALSE if
+ * the foreach operation should stop with %FALSE.
+ *
+ * Since: 1.6
+ */
+typedef gboolean (*GstCapsForeachFunc) (GstCapsFeatures *features,
+                                        GstStructure    *structure,
+                                        gpointer         user_data);
+
+/**
+ * GstCapsMapFunc:
+ * @features: the #GstCapsFeatures
+ * @structure: the #GstStructure
+ * @user_data: user data
+ *
+ * A function that will be called in gst_caps_map_in_place(). The function
+ * may modify @features and @structure.
+ *
+ * Returns: %TRUE if the map operation should continue, %FALSE if
+ * the map operation should stop with %FALSE.
+ */
+typedef gboolean (*GstCapsMapFunc)     (GstCapsFeatures *features,
+                                        GstStructure    *structure,
+                                        gpointer         user_data);
+
+/**
+ * GstCapsFilterMapFunc:
+ * @features: the #GstCapsFeatures
+ * @structure: the #GstStructure
+ * @user_data: user data
+ *
+ * A function that will be called in gst_caps_filter_and_map_in_place().
+ * The function may modify @features and @structure, and both will be
+ * removed from the caps if %FALSE is returned.
+ *
+ * Returns: %TRUE if the features and structure should be preserved,
+ * %FALSE if it should be removed.
+ */
+typedef gboolean (*GstCapsFilterMapFunc) (GstCapsFeatures *features,
+                                          GstStructure    *structure,
+                                          gpointer user_data);
+
+
+GST_EXPORT
 GType             gst_caps_get_type                (void);
 
+GST_EXPORT
 GstCaps *         gst_caps_new_empty               (void);
+
+GST_EXPORT
 GstCaps *         gst_caps_new_any                 (void);
+
+GST_EXPORT
 GstCaps *         gst_caps_new_empty_simple        (const char    *media_type) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_EXPORT
 GstCaps *         gst_caps_new_simple              (const char    *media_type,
                                                     const char    *fieldname,
                                                     ...) G_GNUC_NULL_TERMINATED G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_new_full                (GstStructure  *struct1,
                                                     ...) G_GNUC_NULL_TERMINATED G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_new_full_valist         (GstStructure  *structure,
                                                     va_list        var_args) G_GNUC_WARN_UNUSED_RESULT;
-
+GST_EXPORT
 GType             gst_static_caps_get_type         (void);
+
+GST_EXPORT
 GstCaps *         gst_static_caps_get              (GstStaticCaps *static_caps);
+
+GST_EXPORT
 void              gst_static_caps_cleanup          (GstStaticCaps *static_caps);
 
 /* manipulation */
+
+GST_EXPORT
 void              gst_caps_append                  (GstCaps       *caps1,
                                                     GstCaps       *caps2);
+GST_EXPORT
 void              gst_caps_append_structure        (GstCaps       *caps,
                                                     GstStructure  *structure);
+GST_EXPORT
 void              gst_caps_append_structure_full   (GstCaps       *caps,
                                                     GstStructure  *structure,
                                                     GstCapsFeatures *features);
+GST_EXPORT
 void              gst_caps_remove_structure        (GstCaps       *caps, guint idx);
+
+GST_EXPORT
 GstCaps *         gst_caps_merge                   (GstCaps       *caps1,
                                                     GstCaps       *caps2) G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_merge_structure         (GstCaps       *caps,
                                                     GstStructure  *structure) G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_merge_structure_full    (GstCaps       *caps,
                                                     GstStructure  *structure,
                                                     GstCapsFeatures *features) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_EXPORT
 guint             gst_caps_get_size                (const GstCaps *caps);
+
+GST_EXPORT
 GstStructure *    gst_caps_get_structure           (const GstCaps *caps,
                                                     guint          index);
+GST_EXPORT
 GstStructure *    gst_caps_steal_structure         (GstCaps       *caps,
                                                     guint          index) G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 void              gst_caps_set_features            (GstCaps *caps,
                                                     guint          index,
                                                     GstCapsFeatures * features);
+GST_EXPORT
 GstCapsFeatures * gst_caps_get_features            (const GstCaps *caps,
                                                     guint          index);
+GST_EXPORT
 GstCaps *         gst_caps_copy_nth                (const GstCaps *caps, guint nth) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_EXPORT
 GstCaps *         gst_caps_truncate                (GstCaps       *caps) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_EXPORT
 void              gst_caps_set_value               (GstCaps       *caps,
                                                     const char    *field,
                                                     const GValue  *value);
+GST_EXPORT
 void              gst_caps_set_simple              (GstCaps       *caps,
                                                     const char    *field, ...) G_GNUC_NULL_TERMINATED;
+GST_EXPORT
 void              gst_caps_set_simple_valist       (GstCaps       *caps,
                                                     const char    *field,
                                                     va_list        varargs);
+GST_EXPORT
+gboolean          gst_caps_foreach                 (const GstCaps       *caps,
+                                                    GstCapsForeachFunc   func,
+                                                    gpointer             user_data);
+GST_EXPORT
+gboolean          gst_caps_map_in_place            (GstCaps        *caps,
+                                                    GstCapsMapFunc  func,
+                                                    gpointer        user_data);
+GST_EXPORT
+void              gst_caps_filter_and_map_in_place (GstCaps              *caps,
+                                                    GstCapsFilterMapFunc  func,
+                                                    gpointer              user_data);
 
 /* tests */
+
+GST_EXPORT
 gboolean          gst_caps_is_any                  (const GstCaps *caps);
+
+GST_EXPORT
 gboolean          gst_caps_is_empty                (const GstCaps *caps);
+
+GST_EXPORT
 gboolean          gst_caps_is_fixed                (const GstCaps *caps);
+
+GST_EXPORT
 gboolean          gst_caps_is_always_compatible    (const GstCaps *caps1,
                                                     const GstCaps *caps2);
+GST_EXPORT
 gboolean          gst_caps_is_subset		   (const GstCaps *subset,
 						    const GstCaps *superset);
+GST_EXPORT
 gboolean          gst_caps_is_subset_structure     (const GstCaps *caps,
                                                     const GstStructure *structure);
+GST_EXPORT
 gboolean          gst_caps_is_subset_structure_full (const GstCaps *caps,
                                                      const GstStructure *structure,
                                                      const GstCapsFeatures *features);
+GST_EXPORT
 gboolean          gst_caps_is_equal		   (const GstCaps *caps1,
 						    const GstCaps *caps2);
+GST_EXPORT
 gboolean          gst_caps_is_equal_fixed          (const GstCaps *caps1,
 						    const GstCaps *caps2);
+GST_EXPORT
 gboolean          gst_caps_can_intersect           (const GstCaps * caps1,
 						    const GstCaps * caps2);
+GST_EXPORT
 gboolean          gst_caps_is_strictly_equal	   (const GstCaps *caps1,
 						    const GstCaps *caps2);
 
 
 /* operations */
+
+GST_EXPORT
 GstCaps *         gst_caps_intersect               (GstCaps *caps1,
 						    GstCaps *caps2) G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_intersect_full          (GstCaps *caps1,
 						    GstCaps *caps2,
                                                     GstCapsIntersectMode mode) G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_subtract		   (GstCaps *minuend,
 						    GstCaps *subtrahend) G_GNUC_WARN_UNUSED_RESULT;
+GST_EXPORT
 GstCaps *         gst_caps_normalize               (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
+
+GST_EXPORT
 GstCaps *         gst_caps_simplify                (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
 
+GST_EXPORT
 GstCaps *         gst_caps_fixate                  (GstCaps *caps) G_GNUC_WARN_UNUSED_RESULT;
 
 /* utility */
+
+GST_EXPORT
 gchar *           gst_caps_to_string               (const GstCaps *caps) G_GNUC_MALLOC;
+
+GST_EXPORT
 GstCaps *         gst_caps_from_string             (const gchar   *string) G_GNUC_WARN_UNUSED_RESULT;
 
+#ifdef G_DEFINE_AUTOPTR_CLEANUP_FUNC
+G_DEFINE_AUTOPTR_CLEANUP_FUNC(GstCaps, gst_caps_unref)
+#endif
+
 G_END_DECLS
 
 #endif /* __GST_CAPS_H__ */
